@@ -286,11 +286,11 @@ class ApiGatewayToDynamoDBProps:
         :summary: The properties for the ApiGatewayToDynamoDB class.
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = RestApiProps(**api_gateway_props)
+            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = TableProps(**dynamo_table_props)
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(ApiGatewayToDynamoDBProps.__init__)
             check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
